diff --git a/src/engine.py b/src/engine.py
index bbd637734b0bf1142d7afd387ba46630f4ee3f70..d0829c7b0273b6f3c87e1c58741aab4984ed9510 100644
--- a/src/engine.py
+++ b/src/engine.py
@@ -63,7 +63,7 @@ class Engine():
         Engine.instance = self         
         self.logger = logging.getLogger("AuraEngine")            
         self.config = AuraConfig.config()
-        Engine.engine_time_offset = float(self.config.get("lqs_delay_offset"))
+        Engine.engine_time_offset = float(self.config.get("engine_latency_offset"))
         
         self.plugins = dict()                    
         self.channel_router = ChannelRouter(self.config, self.logger)
@@ -145,7 +145,7 @@ class Engine():
         """
         Liquidsoap is slow in executing commands, therefore it's needed to schedule
         actions by (n) seconds in advance, as defined in the configuration file by
         the property `lqs_delay_offset`. it's important to note that this method
         requires the class variable `EngineUtil.engine_time_offset` to be set on
         Engine initialization.
@@ -145,7 +145,7 @@ class Engine():
         Liquidsoap is slow in executing commands, therefore it's needed to schedule
         actions by (n) seconds in advance, as defined in the configuration file by
-        the property `lqs_delay_offset`. it's important to note that this method
+        the property `engine_latency_offset`. it's important to note that this method
         requires the class variable `EngineUtil.engine_time_offset` to be set on
         Engine initialization.